{% load i18n %}
<div class="row section">
  <div class="col-xl-12 section-content">
    {% block column_section_data %}
    <div class="row">
      <div class="col-xl-12">
        <div class="section-header {% block section_header_extra_class %}{% endblock %}"> 
          <div class="row">
            <div class="col-xl-11">
              <div class="section-title">{% block section_title %}{% endblock %}</div>
            </div>
            <div class="col-xl-1">
              <div class="section-buttons float-right">
                <div class="section-favorite text-right">
                  {% block section_favorite %}{% endblock %}
                </div>
                {% if not preview %}
                {% block section_buttons_dropdown %}
                <div class="dropdown">
                    <button class="btn btn-xs dropdown-toggle btn-secondary" id="dropdown-action" data-toggle="dropdown" aria-haspopup="true"  href="#" aria-expanded="false" type="button">
                      {% block section_menu_name %}<i class="fas fa-cog"></i>{% endblock %}
                      <span class="caret"></span>
                    </button>
                    <div class="dropdown-menu" aria-labelledby="dropdown-action">
                        {% block section_buttons %}{% endblock %}
                    </div>
                </div>
                {% endblock %}
                {% block section_buttons_extra %}{% endblock %}
                {% endif %}
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
    <div class="row"><div class="col-xl-12 section-data">
      {% block section_data %}
      {% endblock %}
    </div></div>
    {% endblock %}
  </div>
</div>