# Generated by Django 2.2.9 on 2020-02-10 14:36

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Users', '0005_auto_20190719_0947'),
    ]

    operations = [
        migrations.AlterField(
            model_name='custommenuitem',
            name='only_for_users',
            field=models.ManyToManyField(blank=True, limit_choices_to={'is_staff': True}, to=settings.AUTH_USER_MODEL, verbose_name='only for users'),
        ),
    ]
