# Generated by Django 2.2.17 on 2020-12-02 17:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Crm', '0030_group_on_contacts_list'),
    ]

    operations = [
        migrations.AddField(
            model_name='actionmenu',
            name='css_class',
            field=models.CharField(blank=True, default='', help_text='Example: "colorbox-form" for colorbox display', max_length=50, verbose_name='CSS class'),
        ),
        migrations.AlterField(
            model_name='actionmenu',
            name='a_attrs',
            field=models.CharField(blank=True, default='', help_text='Example: target="_blank"', max_length=50, verbose_name='Link args'),
        ),
    ]
