# Generated by Django 2.2.17 on 2020-11-27 14:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Store', '0020_sale_delivery_details'),
    ]

    operations = [
        migrations.AddField(
            model_name='saleitem',
            name='is_extra',
            field=models.BooleanField(default=False, help_text='added after total on the bill', verbose_name='is extra'),
        ),
    ]
