{% load i18n %}

<span class="cursor-pointer favorite-icon {%if status %}in-fav{% else %}out-fav{% endif %}">
    <i class="{%if not status %}far{% else %} fas{% endif %} fa-star"></i>
    <form style="display:none" action="{{post_url}}">{% csrf_token %}{{ form.as_p }}</form>
</span>