# Generated by Django 2.2.18 on 2021-05-13 17:10

from django.db import migrations, models
import django.db.models.manager


class Migration(migrations.Migration):

    dependencies = [
        ('Crm', '0032_auto_20210223_0940'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='contact',
            managers=[
                ('all_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='entity',
            managers=[
                ('all_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AddField(
            model_name='contact',
            name='confirmed',
            field=models.BooleanField(db_index=True, default=True, help_text='For contact created from subscription form, we need to wait for confirmation by email link', verbose_name='confirmed'),
        ),
        migrations.AddField(
            model_name='entity',
            name='confirmed',
            field=models.BooleanField(db_index=True, default=True, help_text='For contact created from subscription form, we need to wait for confirmation by email link', verbose_name='confirmed'),
        ),
    ]
