# Generated by Django 2.2.17 on 2020-11-26 21:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Store', '0018_sale_details'),
    ]

    operations = [
        migrations.CreateModel(
            name='Voucher',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('code', models.CharField(max_length=100, verbose_name='code')),
                ('start_date', models.DateField(verbose_name='start date')),
                ('end_date', models.DateField(verbose_name='end date')),
                ('rate', models.DecimalField(decimal_places=2, default=0, max_digits=4, verbose_name='rate')),
                ('active', models.BooleanField(default=False, verbose_name='active')),
            ],
            options={
                'verbose_name': 'Voucher',
                'verbose_name_plural': 'Vouchers',
                'ordering': ['-start_date', 'end_date'],
            },
        ),
    ]
