<!DOCYTPE HTML><html lang="fr">{% load i18n balafon_utils static %}
<head>
  <meta charset="utf-8">
  <title>{% block title %}{{ subject }}{% endblock %}</title>
  <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <meta http-equiv="X-UA-Compatible" content="IE=edge" />
  {% block head %}{% endblock %}
  {% block extra_head %}{% endblock %}
  </head>
  <body>
  {% block header_banner %}{% endblock %}
  {% block content %}{% endblock %}
  {% block footer_banner %}{% endblock %}
  </body>
</html>
