{% extends "balafon/email_base.html" %}
{% load i18n balafon_utils %}

{% block content %}{% spaceless %}
<table width="100%" align="center" cellpadding="0" cellspacing="0" border="0">
  {% url "registration_activate" activation_key as activation_url %}
  <tr>
    <td>
{% blocktrans %}
Hello,
You have requested to create an account on {{site}}.
We are happy to welcome you on the site. We hope you will enjoy it.

In order to finish the account creation, please activate your account by visiting the following url:
{% endblocktrans %}
    </td>
  </tr>

  <tr>
    <td>
      <table>
        <tr>
          <td>
            <a href="{{ activation_url|full_path_url }}" target="_blank">
                {% trans "Account activation" %}
            </a>
          </td>
        </tr>
      </table>
    </td>
  </tr>

  <tr>
    <td>
{% blocktrans %}
If you did not request this account creation, please ignore this email.
{% endblocktrans %}
    </td>
  </tr>
</table>
{% endspaceless %}
{% endblock %}
