# Generated by Django 2.2.17 on 2020-11-23 17:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Store', '0017_auto_20180928_1358'),
    ]

    operations = [
        migrations.AddField(
            model_name='sale',
            name='details',
            field=models.TextField(blank=True, default=''),
        ),
    ]
