{% extends "balafon/bs_base.html" %}{% load i18n %}

{% block header_bar %}
{% endblock %}
  
  
{% block main %}
<div class="login-header">
    <i class="fa fa-address-book"></i> Balafon
</div>
{% block registration_content %}
{% endblock %}
{% endblock %}
