# Generated by Django 2.2.14 on 2020-12-15 10:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Users', '0006_auto_20200210_1436'),
    ]

    operations = [
        migrations.AddField(
            model_name='custommenuitem',
            name='query_string',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='query string'),
        ),
    ]
